# NanopolishComp

[![GitHub license](https://img.shields.io/github/license/a-slide/NanopolishComp.svg)](https://github.com/a-slide/NanopolishComp/blob/master/LICENSE)
[![Language](https://img.shields.io/badge/Language-Python3-yellow.svg)](https://www.python.org/)
[![PyPI version](https://badge.fury.io/py/NanopolishComp.svg)](https://badge.fury.io/py/NanopolishComp)
[![PyPI downloads](https://pepy.tech/badge/nanopolishcomp)](https://pepy.tech/project/nanopolishcomp)
[![DOI](https://zenodo.org/badge/144169864.svg)](https://zenodo.org/badge/latestdoi/144169864)

**NanopolishComp is a Python3 package for downstream analyses of Nanopolish output files**

Full documentation is available at https://a-slide.github.io/NanopolishComp/

Please be aware that NanopolishComp is a research package that is still under development.

It was tested under Linux Ubuntu 16.04 and in an HPC environment running under Red Hat Enterprise 7.1.

Thank you

### Authors

* Adrien Leger - aleg {at} ebi.ac.uk
